% demo07a    --- extremes of effect of varying spline parameter on spline fit to 
%  sunspot number
%
% Illustrates:
% -call to spline toolbox function csaps
% -effect of varying spline parameter on flexibility
% -"variance explained" statistic as summary of importance of trend


clear;
close all;

% Load data
% Sunspot series is in V3
fnm1 ='Spring19.mat';

eval(['load ' fnm1 ';']);


% Store year as vector yr, sunspot number as vector x
yrx=V3.time; 
x= V3.tsm(:,1); % yearly sunspot number

[x,yrx]=trimnan(x,yrx);x

xlims=[yrx(1) yrx(end)];
T=x;
yr=yrx;

meanT=mean(T);

kwhile1=1; % control for outer while-loop
kfirst=1;

% Initial plot of time series
hp1=plot(yr,T,xlims,[meanT meanT]);
set(hp1(1),'Linewidth',2);
set(hp1(2),'Linewidth',1,'LineStyle','--');
title('Annual Sunspot Number, T','FontSize',14);
xlabel('Year','FontSize',14)
ylabel('SS #','FontSize',14);
grid;
zoom xon;
set(gca,'XLim',xlims,'FontSize',12);
textcorn('Dashed line at mean','UL',0.02,0.02,11);


pinit=0; % initial setting of parameter is straight line fit
pold=pinit;

while kwhile1;  % Outer while loop 
   kmen1=menu('Choose','Set or change spline parameter','Quit');
   if kmen1==1;
       
       
       kwhile2=1;
       while kwhile2==1;  % Inner while loop
            prompt={'Enter parameter:'};
           def={num2str(pold)};
           dlgTitle='Spline Parameter (must be between 0 and 1';
           lineNo=1;
           answer=inputdlg(prompt,dlgTitle,lineNo,def);
           p=str2num(answer{1});
           if p<0 | p>1;
               uiwait(msgbox('Parameter cannot be <0 ir >1','modal'));
               kwhile2=1;
           else;
               kwhile2=0;
               pold=p;
           end;
           
       end; % while kwhile2==1;
       
      
      %-------- COMPUTE THE SMOOTHING SPLINE
      
      s=csaps(yr,T,p,yr);
      
      
      %--------- COMPUTE VARIANCE ACCOUNTED FOR BY SPLINE
      
      e = T-s;  % difference of original series and fitted line
      pct=1-var(e)/var(T);
      strpct=['Fraction of variance explained by trend = 1 - var(e)/var(T) = ' num2str(pct,'%6.2f')];
      
      
      % -- Plot original and spline-smoothed series
      hp1=plot(yr,T,yr,s,xlims,[meanT meanT]);
      set(hp1(1),'LineWidth',2);
      set(hp1(2),'LineWidth',2);
      set(hp1(3),'Linewidth',1,'LineStyle','--');
      title('Spline fit to sunspot number','FontSize',14);
      xlabel('Year','FontSize',14)
      ylabel('Sunspot number','FontSize',14);
      strp=['Spline parameter, p = ', num2str(p)];
      
      str1={strp,strpct};
      textcorn(str1,'UL',0.02,0.02,11);
      %text(1702,171,{strp,strpct},'FontSize',11);
      grid;
      zoom xon;
      set(gca,'XLim',xlims,'FontSize',12);
      figure(1);
      kwhile1=1;
   else;
      kwhile1=0;
     
   end;
end;

    